@@ -16,20 +16,19 @@ class BunkrCrawler:
         self.SQL_Helper = SQL_Helper
         self.remove_bunkr_id = remove_bunkr_id
 
-    async def fetch(self, session: ScrapeSession, url: URL):
+    async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Scraper for Bunkr"""
         album_obj = AlbumItem("Loose Bunkr Files", [])
-        await log(f"[green]Starting: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
 
         if "v" in url.parts or "d" in url.parts:
             media = await self.get_file(session, url)
             if not media.filename:
                 return album_obj
             await album_obj.add_media(media)
-            await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+            await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
             if not media.complete:
-                url_path = await get_db_path(url)
-                await self.SQL_Helper.insert_media("bunkr", url_path, "", str(url), "", "", media.filename, 0)
+                await self.SQL_Helper.insert_media("bunkr", "", media)
             return album_obj
 
         if "a" in url.parts:
@@ -38,7 +37,7 @@ class BunkrCrawler:
             await self.SQL_Helper.insert_album("bunkr", url_path, album_obj)
 
             if album_obj.media:
-                await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+                await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
             return album_obj
 
         cdn_possibilities = r"(?:cdn.bunkr...|cdn..bunkr...|cdn...bunkr...|media-files.bunkr...|media-files..bunkr...|media-files...bunkr...)"
@@ -47,7 +46,7 @@ class BunkrCrawler:
             ext = ext.lower()
         if ext in FILE_FORMATS['Images']:
             filename, ext = await get_filename_and_ext(url.name)
-            original_filename, filename = self.remove_id(filename, ext)
+            original_filename, filename = await self.remove_id(filename, ext)
 
             url_path = await get_db_path(url)
             await self.SQL_Helper.fix_bunkr_entries(url_path, original_filename)
@@ -65,7 +64,7 @@ class BunkrCrawler:
             await album_obj.add_media(media_item)
 
         await self.SQL_Helper.insert_album("bunkr", url.path, album_obj)
-        await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
         return album_obj
 
     async def remove_id(self, filename: str, ext: str):
@@ -109,15 +108,11 @@ class BunkrCrawler:
             url_path = await get_db_path(link)
             await self.SQL_Helper.fix_bunkr_entries(url_path, original_filename)
             complete = await self.SQL_Helper.check_complete_singular("bunkr", url_path)
-            if complete:
-                media = MediaItem(link, url, True, filename, ext, original_filename)
-                return media
-            media = MediaItem(link, url, False, filename, ext, original_filename)
-            return media
+            return MediaItem(link, url, complete, filename, ext, original_filename)
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             logger.debug(e)
             return MediaItem(url, url, False, "", "", "")
 
@@ -167,7 +162,7 @@ class BunkrCrawler:
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             logger.debug(e)
 
         return album
