@@ -14,11 +14,11 @@ class CyberdropCrawler:
         self.SQL_Helper = SQL_Helper
         self.quiet = quiet
 
-    async def fetch(self, session: ScrapeSession, url: URL):
+    async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Cyberdrop scraper"""
         album_obj = AlbumItem("Loose Cyberdrop Files", [])
 
-        await log(f"[green]Starting: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
         if await check_direct(url):
             url_path = await get_db_path(url)
             complete = await self.SQL_Helper.check_complete_singular("cyberdrop", url_path)
@@ -26,7 +26,7 @@ class CyberdropCrawler:
             media = MediaItem(url, url, complete, filename, ext, filename)
             await album_obj.add_media(media)
             await self.SQL_Helper.insert_album("cyberdrop", "", album_obj)
-            await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+            await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
             return album_obj
 
         try:
@@ -40,16 +40,16 @@ class CyberdropCrawler:
                 media = MediaItem(url, url, complete, filename, ext, filename)
                 await album_obj.add_media(media)
                 await self.SQL_Helper.insert_album("cyberdrop", "", album_obj)
-                await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+                await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
                 return album_obj
 
             title = soup.select_one("h1[id=title]").get_text()
+            title = await make_title_safe(title.replace("\n", "").strip())
             if title is None:
                 title = url.name
             elif self.include_id:
                 titlep2 = url.name
                 title = title + " - " + titlep2
-            title = await make_title_safe(title.replace(r"\n", "").strip())
             await album_obj.set_new_title(title)
 
             links = soup.select('div[class="image-container column"] a')
@@ -68,11 +68,11 @@ class CyberdropCrawler:
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             logger.debug(e)
             return album_obj
 
         url_path = await get_db_path(url)
         await self.SQL_Helper.insert_album("cyberdrop", url_path, album_obj)
-        await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
         return album_obj
