@@ -32,7 +32,7 @@ class GoFileCrawler:
                 raise
         except Exception as e:
             logger.debug("Error encountered while getting GoFile token", exc_info=True)
-            await log("[red]Error: Couldn't generate GoFile token[/red]", quiet=self.quiet)
+            await log("Error: Couldn't generate GoFile token", quiet=self.quiet, style="red")
             logger.debug(e)
 
     async def set_cookie(self, session: ScrapeSession):
@@ -43,11 +43,11 @@ class GoFileCrawler:
         morsel.set('accountToken', client_token, client_token)
         session.client_session.cookie_jar.update_cookies({'gofile.io': morsel})
 
-    async def fetch(self, session: ScrapeSession, url: URL):
+    async def fetch(self, session: ScrapeSession, url: URL) -> DomainItem:
         """Basic director for actual scraping"""
+        domain_obj = DomainItem("gofile", {})
         try:
-            await log(f"[green]Starting: {str(url)}[/green]", quiet=self.quiet)
-            domain_obj = DomainItem("gofile", {})
+            await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
             content_id = url.name
             results = await self.get_links(session, url, content_id, None)
             for title, media_item in results:
@@ -55,14 +55,14 @@ class GoFileCrawler:
 
             url_path = await get_db_path(url)
             await self.SQL_Helper.insert_domain("gofile", url_path, domain_obj)
-            await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
-            return domain_obj
-
+            await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             logger.debug(e)
 
+        return domain_obj
+
     async def get_links(self, session: ScrapeSession, url: URL, content_id: str, title=None):
         """Gets links from the given url, creates media_items"""
         results = []
@@ -74,7 +74,7 @@ class GoFileCrawler:
         content = await session.get_json_with_params(self.api_address / "getContent", params)
         if content["status"] != "ok":
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             return results
 
         content = content['data']
