@@ -13,9 +13,9 @@ class PixelDrainCrawler:
         self.SQL_Helper = SQL_Helper
         self.api = URL('https://pixeldrain.com/api/')
 
-    async def fetch(self, session: ScrapeSession, url: URL):
+    async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Director for pixeldrain scraping"""
-        await log(f"[green]Starting: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
         album_obj = AlbumItem("Loose Pixeldrain Files", [])
 
         identifier = str(url).split('/')[-1]
@@ -28,13 +28,13 @@ class PixelDrainCrawler:
         else:
             link = await self.create_download_link(identifier)
             url_path = await get_db_path(link)
-            complete = await self.SQL_Helper.check_complete_singular("anonfiles", url_path)
+            complete = await self.SQL_Helper.check_complete_singular("pixeldrain", url_path)
             filename, ext = await get_filename_and_ext(await self.get_file_name(session, identifier))
             media_item = MediaItem(link, url, complete, filename, ext, filename)
             await album_obj.add_media(media_item)
 
         await self.SQL_Helper.insert_album("pixeldrain", url.path, album_obj)
-        await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
         return album_obj
 
     async def get_listings(self, session: ScrapeSession, identifier: str, url: URL):
@@ -57,7 +57,7 @@ class PixelDrainCrawler:
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"[red]Error: {str(url)}[/red]", quiet=self.quiet)
+            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
             logger.debug(e)
 
     async def get_file_name(self, session: ScrapeSession, identifier: str):
