@@ -12,7 +12,7 @@ class XBunkrCrawler:
         self.quiet = quiet
         self.SQL_Helper = SQL_Helper
 
-    async def fetch(self, session: ScrapeSession, url: URL):
+    async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Director for XBunkr scraping"""
         album_obj = AlbumItem("Loose XBunkr Files", [])
 
@@ -48,5 +48,5 @@ class XBunkrCrawler:
             logger.debug(e)
 
         await self.SQL_Helper.insert_album("xbunkr", "", album_obj)
-        await log(f"[green]Finished: {str(url)}[/green]", quiet=self.quiet)
+        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
         return album_obj
