@@ -1,5 +1,5 @@
 import asyncio
-from typing import Dict, Optional
+from typing import Dict
 
 import aiofiles
 from yarl import URL
@@ -100,21 +100,21 @@ class ScrapeMapper:
                         "coomer.party": self.Coomeno, "kemono.party": self.Coomeno,
                         "simpcity": self.Xenforo, "socialmediagirls": self.Xenforo, "xbunker": self.Xenforo}
 
-    async def handle_additions(self, domain: str, album_obj: Optional[AlbumItem], domain_obj: Optional[DomainItem], title=None):
-        if album_obj:
-            if title:
-                await album_obj.append_title(title)
-                await self.Forums.add_album_to_thread(title, domain, album_obj)
-            else:
-                await self.Cascade.add_album(domain, album_obj.title, album_obj)
-        if domain_obj:
-            if title:
-                await domain_obj.append_title(title)
-                for album_title, album in domain_obj.albums.items():
-                    await self.Forums.add_album_to_thread(title, domain, album)
-            else:
-                for title, album in domain_obj.albums.items():
-                    await self.Cascade.add_album(domain, album.title, album)
+    async def _handle_album_additions(self, domain: str, album_obj: AlbumItem, title=None) -> None:
+        if title:
+            await album_obj.append_title(title)
+            await self.Forums.add_album_to_thread(title, domain, album_obj)
+        else:
+            await self.Cascade.add_album(domain, album_obj.title, album_obj)
+
+    async def _handle_domain_additions(self, domain: str, domain_obj: DomainItem, title=None) -> None:
+        if title:
+            await domain_obj.append_title(title)
+            for album in domain_obj.albums.values():
+                await self.Forums.add_album_to_thread(title, domain, album)
+        else:
+            for album in domain_obj.albums.values():
+                await self.Cascade.add_album(domain, album.title, album)
 
     """Redirection handler for Simp City"""
 
@@ -129,7 +129,7 @@ class ScrapeMapper:
         if not self.anonfiles_crawler:
             self.anonfiles_crawler = AnonfilesCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.anonfiles_crawler.fetch(anonfiles_session, url)
-        await self.handle_additions("anonfiles", album_obj, None, title)
+        await self._handle_album_additions("anonfiles", album_obj, title)
         await anonfiles_session.exit_handler()
 
     async def Bunkr(self, url: URL, title=None):
@@ -140,7 +140,7 @@ class ScrapeMapper:
         async with self.bunkr_limiter:
             album_obj = await self.bunkr_crawler.fetch(bunkr_session, url)
         if not await album_obj.is_empty():
-            await self.handle_additions("bunkr", album_obj, None, title)
+            await self._handle_album_additions("bunkr", album_obj, title)
         await bunkr_session.exit_handler()
 
     async def Cyberdrop(self, url: URL, title=None):
@@ -148,7 +148,7 @@ class ScrapeMapper:
         if not self.cyberdrop_crawler:
             self.cyberdrop_crawler = CyberdropCrawler(include_id=self.include_id, quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.cyberdrop_crawler.fetch(cyberdrop_session, url)
-        await self.handle_additions("cyberdrop", album_obj, None, title)
+        await self._handle_album_additions("cyberdrop", album_obj, title)
         await cyberdrop_session.exit_handler()
 
     async def CyberFile(self, url, title=None):
@@ -157,7 +157,7 @@ class ScrapeMapper:
             self.cyberfile_crawler = CyberFileCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         async with self.cyberfile_semaphore:
             domain_obj = await self.cyberfile_crawler.fetch(cyberfile_session, url)
-        await self.handle_additions("cyberfile", None, domain_obj, title)
+        await self._handle_domain_additions("cyberfile", domain_obj, title)
         await cyberfile_session.exit_handler()
 
     async def EHentai(self, url, title=None):
@@ -165,7 +165,7 @@ class ScrapeMapper:
         if not self.ehentai_crawler:
             self.ehentai_crawler = EHentaiCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.ehentai_crawler.fetch(ehentai_session, url)
-        await self.handle_additions("e-hentai", album_obj, None, title)
+        await self._handle_album_additions("e-hentai", album_obj, title)
         await ehentai_session.exit_handler()
 
     async def Erome(self, url, title=None):
@@ -173,7 +173,7 @@ class ScrapeMapper:
         if not self.erome_crawler:
             self.erome_crawler = EromeCrawler(include_id=self.include_id, quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         domain_obj = await self.erome_crawler.fetch(erome_session, url)
-        await self.handle_additions("erome", None, domain_obj, title)
+        await self._handle_domain_additions("erome", domain_obj, title)
         await erome_session.exit_handler()
 
     async def Gfycat(self, url, title=None):
@@ -181,7 +181,7 @@ class ScrapeMapper:
         if not self.gfycat_crawler:
             self.gfycat_crawler = GfycatCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.gfycat_crawler.fetch(gfycat_session, url)
-        await self.handle_additions("gfycat", album_obj, None, title)
+        await self._handle_album_additions("gfycat", album_obj, title)
         await gfycat_session.exit_handler()
 
     async def GoFile(self, url, title=None):
@@ -192,7 +192,7 @@ class ScrapeMapper:
             await self.gofile_crawler.get_token(session=gofile_session)
         async with self.gofile_limiter:
             domain_obj = await self.gofile_crawler.fetch(gofile_session, url)
-        await self.handle_additions("gofile", None, domain_obj, title)
+        await self._handle_domain_additions("gofile", domain_obj, title)
         await gofile_session.exit_handler()
 
     async def HGameCG(self, url, title=None):
@@ -200,7 +200,7 @@ class ScrapeMapper:
         if not self.hgamecg_crawler:
             self.hgamecg_crawler = HGameCGCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.hgamecg_crawler.fetch(hgamecg_session, url)
-        await self.handle_additions("hgamecg", album_obj, None, title)
+        await self._handle_album_additions("hgamecg", album_obj, title)
         await hgamecg_session.exit_handler()
 
     async def ImgBox(self, url, title=None):
@@ -208,7 +208,7 @@ class ScrapeMapper:
         if not self.imgbox_crawler:
             self.imgbox_crawler = ImgBoxCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.imgbox_crawler.fetch(imgbox_session, url)
-        await self.handle_additions("imgbox", album_obj, None, title)
+        await self._handle_album_additions("imgbox", album_obj, title)
         await imgbox_session.exit_handler()
 
     async def LoveFap(self, url: URL, title=None):
@@ -216,7 +216,7 @@ class ScrapeMapper:
         if not self.lovefap_crawler:
             self.lovefap_crawler = LoveFapCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.lovefap_crawler.fetch(lovefap_session, url)
-        await self.handle_additions("lovefap", album_obj, None, title)
+        await self._handle_album_additions("lovefap", album_obj, title)
         await lovefap_session.exit_handler()
 
     async def PimpAndHost(self, url, title=None):
@@ -224,7 +224,7 @@ class ScrapeMapper:
         if not self.pimpandhost_crawler:
             self.pimpandhost_crawler = PimpAndHostCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.pimpandhost_crawler.fetch(pimpandhost_session, url)
-        await self.handle_additions("pimpandhost", album_obj, None, title)
+        await self._handle_album_additions("pimpandhost", album_obj, title)
         await pimpandhost_session.exit_handler()
 
     async def PixelDrain(self, url, title=None):
@@ -232,7 +232,7 @@ class ScrapeMapper:
         if not self.pixeldrain_crawler:
             self.pixeldrain_crawler = PixelDrainCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.pixeldrain_crawler.fetch(pixeldrain_session, url)
-        await self.handle_additions("pixeldrain", album_obj, None, title)
+        await self._handle_album_additions("pixeldrain", album_obj, title)
         await pixeldrain_session.exit_handler()
 
     async def PostImg(self, url, title=None):
@@ -240,7 +240,7 @@ class ScrapeMapper:
         if not self.postimg_crawler:
             self.postimg_crawler = PostImgCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.postimg_crawler.fetch(postimg_session, url)
-        await self.handle_additions("postimg", album_obj, None, title)
+        await self._handle_album_additions("postimg", album_obj, title)
         await postimg_session.exit_handler()
 
     async def Saint(self, url, title=None):
@@ -248,7 +248,7 @@ class ScrapeMapper:
         if not self.saint_crawler:
             self.saint_crawler = SaintCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.saint_crawler.fetch(saint_session, url)
-        await self.handle_additions("saint", album_obj, None, title)
+        await self._handle_album_additions("saint", album_obj, title)
         await saint_session.exit_handler()
 
     async def ShareX(self, url, title=None):
@@ -261,7 +261,7 @@ class ScrapeMapper:
                     domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
         else:
             domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
-        await self.handle_additions("sharex", None, domain_obj, title)
+        await self._handle_domain_additions("sharex", domain_obj, title)
         await sharex_session.exit_handler()
 
     async def XBunkr(self, url, title=None):
@@ -269,7 +269,7 @@ class ScrapeMapper:
         if not self.xbunkr_crawler:
             self.xbunkr_crawler = XBunkrCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.xbunkr_crawler.fetch(xbunkr_session, url)
-        await self.handle_additions("xbunkr", album_obj, None, title)
+        await self._handle_album_additions("xbunkr", album_obj, title)
         await xbunkr_session.exit_handler()
 
     """Archive Sites"""
@@ -279,7 +279,8 @@ class ScrapeMapper:
         if not self.fapello_crawler:
             self.fapello_crawler = FapelloCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         album_obj = await self.fapello_crawler.fetch(fapello_session, url)
-        await self.handle_additions("fapello", album_obj, None, title)
+        if album_obj:
+            await self._handle_album_additions("fapello", album_obj, title)
         await fapello_session.exit_handler()
 
     async def NSFW_XXX(self, url, title=None):
@@ -287,7 +288,7 @@ class ScrapeMapper:
         if not self.nsfwxxx_crawler:
             self.nsfwxxx_crawler = NSFWXXXCrawler(separate_posts=self.separate_posts, quiet=self.quiet, SQL_Helper=self.SQL_Helper)
         domain_obj = await self.nsfwxxx_crawler.fetch(nsfwxxx_session, url)
-        await self.handle_additions("nsfw.xxx", None, domain_obj, title)
+        await self._handle_domain_additions("nsfw.xxx", domain_obj, title)
         await nsfwxxx_session.exit_handler()
 
     async def Coomeno(self, url: URL, title=None):
@@ -338,21 +339,23 @@ class ScrapeMapper:
     async def map_url(self, url_to_map: URL, title=None, referer=None):
         if not url_to_map:
             return
-        elif not url_to_map.host:
-            await log(f"[yellow]Not Supported: {str(url_to_map)}[/yellow]", quiet=self.quiet)
+        if not url_to_map.host:
+            await log(f"Not Supported: {str(url_to_map)}", quiet=self.quiet, style="yellow")
             return
-        for key, value in self.mapping.items():
-            if key in url_to_map.host:
-                if self.only_data.sites:
-                    if any(site in key for site in self.only_data.sites):
-                        await value(url=url_to_map, title=title)
-                    else:
-                        await log(f"[yellow]Skipping: {str(url_to_map)}[/yellow]", quiet=self.quiet)
-                elif any(site in key for site in self.skip_data.sites):
-                    await log(f"[yellow]Skipping: {str(url_to_map)}[/yellow]", quiet=self.quiet)
+
+        key = next((key for key in self.mapping if key in url_to_map.host), None)
+        if key:
+            handler = self.mapping[key]
+            if self.only_data.sites:
+                if any(site in key for site in self.only_data.sites):
+                    await handler(url=url_to_map, title=title)
                 else:
-                    await value(url=url_to_map, title=title)
-                return
+                    await log(f"Skipping: {str(url_to_map)}", quiet=self.quiet, style="yellow")
+            elif any(site in key for site in self.skip_data.sites):
+                await log(f"Skipping: {str(url_to_map)}", quiet=self.quiet, style="yellow")
+            else:
+                await handler(url=url_to_map, title=title)
+            return
 
         if self.jdownloader.jdownloader_enable:
             async with asyncio.Semaphore(1):
@@ -362,7 +365,7 @@ class ScrapeMapper:
             await self.jdownloader.direct_unsupported_to_jdownloader(url_to_map, title)
 
         else:
-            await log(f"[yellow]Not Supported: {str(url_to_map)}[/yellow]", quiet=self.quiet)
+            await log(f"Not Supported: {str(url_to_map)}", quiet=self.quiet, style="yellow")
             if self.unsupported_output:
                 title = title.encode("ascii", "ignore")
                 title = title.decode().strip()
